{pkgs, lib, ...}:
{
	nixpkgs.config.allowUnfreePredicate = pkg: builtins.elem (lib.getName pkg) [
		"ookla-speedtest"
	];
	home.packages = with pkgs; [
		(python3.withPackages(ps: with ps; [
			# ansible
			dnspython
			youtube-dl
			boto3 # aws-s3 support for ansible
			kubernetes #  is in ansible kubernetes.core module
			# dict_utils for an ansible filter_plugin
			setuptools
			deepmerge
			pip
			passlib # bcrypt
		]))
		ansible
		killall
		tree
		htop
		mosh
		git
		pre-commit
		git-lfs
		git-crypt
		git-annex
		ghorg
		tig
		tea
		glab
		figlet
		tmux
		w3m
		wget
		xh
		minio-client
		liboping # fix it
		mtr
		ookla-speedtest
		colordiff
		direnv
		# nice prompt together with grml
		pure-prompt
		#vimPlugins.nvim-lspconfig
		#vimPlugins.nerdtree
		go gcc libcap
		gopls
		cargo
		yarn
		cmake
		pwgen
		gotify-cli
		glow
		imagemagick
		ffmpeg
		# devOps
		terraform
		tflint
		kubectl
		kubernetes-helm
		helmfile
		k9s
		# nixopsUnstable
	];

	programs.password-store = {
		enable = true;
		package = pkgs.pass-wayland.withExtensions (exts: [
			exts.pass-otp
		]);
		settings = {
			PASSWORD_STORE_DIR = "$HOME/.password-store";
		};
	};

	programs.zsh = {
		enable = true;

		enableAutosuggestions = true;
		enableSyntaxHighlighting = true;
		initExtra = ''
			source ${pkgs.grml-zsh-config}/etc/zsh/zshrc
			prompt pure
		'';
	};
	programs.direnv.enable = true;
	programs.gitui.enable = true;

	programs.neovim = {
		enable = true;
		extraConfig = ''
		syntax on
		set number relativenumber
		'';
		plugins = with pkgs.vimPlugins; [
			nvim-lspconfig
			airline
			Syntastic
			{
				plugin = nerdtree;
				config = "map <C-n> :NERDTreeToggle<CR>";
			}
		];
	};
}
